# -*- coding: utf-8 -*-
##############################################################################
#
# Gestion scolarite IUT
#
# Copyright (c) 1999 - 2025 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@viennet.net
#
##############################################################################

"""Vues AutoSco"""

from flask import flash, redirect, render_template, url_for
from flask import g, request

from app import db
from app.autosco import bp
from app.decorators import (
    scodoc,
    permission_required,
)
from app.models import (
    FormSemestre,
    FormSemestreDemandeInscription,
    StatutDemandeInscription,
)
from app.scodoc.sco_permissions import Permission
from app.scodoc import sco_utils as scu
from app.views import ScoData


@bp.route("/formsemestre/<int:formsemestre_id>/demandes_inscriptions", methods=["GET"])
@scodoc
@permission_required(Permission.EtudInscrit)
def formsemestre_demandes_inscriptions(formsemestre_id: int):
    "Liste les demandes d'inscriptions pour ce semestre"
    formsemestre = FormSemestre.get_formsemestre(formsemestre_id)
    return render_template(
        "autosco/formsemestre_demandes_inscriptions.j2",
        formsemestre=formsemestre,
        demandes_inscriptions=formsemestre.demandes_inscriptions,
        sco=ScoData(formsemestre=formsemestre),
    )


@bp.route("/demande_inscription/<string:numero>", methods=["GET"])
@scodoc
@permission_required(Permission.EtudInscrit)
def demande_inscription(numero: str):
    "Affiche une demande d'inscriptions pour ce semestre"
    demande = (
        db.session.query(FormSemestreDemandeInscription)
        .filter_by(numero=numero)
        .first_or_404()
    )
    formsemestre = FormSemestre.get_formsemestre(demande.formsemestre_id)

    image_piece_jointe = demande.piece_jointe and (
        scu.detect_file_type(demande.piece_jointe) in ("jpeg", "png")
    )
    return render_template(
        "autosco/demande_inscription.j2",
        demande=demande,
        formsemestre=formsemestre,
        image_piece_jointe=image_piece_jointe,
        sco=ScoData(formsemestre=formsemestre),
    )
